@@ -1,6 +1,6 @@
 package Markdown::Pod::script;
 {
-  $Markdown::Pod::script::VERSION = '0.004';
+  $Markdown::Pod::script::VERSION = '0.005';
 }
 # ABSTRACT: script to convert Markdown to POD
 
@@ -8,7 +8,6 @@ use strict;
 use warnings;
 
 use Encode qw( encodings decode );
-use File::Slurp;
 use Getopt::Long;
 use List::Util qw( first );
 use Markdown::Pod;
@@ -45,7 +44,7 @@ sub doit {
     my $m2p  = Markdown::Pod->new;
 
     if ( $self->{load_from_stdin} ) {
-        my $markdown = read_file(\*STDIN);
+        my $markdown = do { local $/; <STDIN>; };
 
         my $pod = $m2p->markdown_to_pod(
             encoding => $self->{encoding},
@@ -55,9 +54,14 @@ sub doit {
     }
 
     for my $file ( @{$self->{argv}} ) {
+        open my $fh, $file
+            or warn("cannot open $file: $!\n"), next;
+        my $markdown = do { local $/; <$fh>; };
+        close $fh;
+
         my $pod = $m2p->markdown_to_pod(
             encoding => $self->{encoding},
-            markdown => scalar( read_file($file) ),
+            markdown => $markdown,
         );
         print $self->{encoding} ? decode( $self->{encoding}, $pod ) : $pod;
     }
@@ -137,7 +141,7 @@ Markdown::Pod::script - script to convert Markdown to POD
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
